﻿using System;
using System.Collections.Generic;
using System.Globalization;
using System.IO;
using Virinco.WATS.Interface;

namespace $safeprojectname$
{
    public class SimpleConverter : IReportConverter_v2
    {
        Dictionary<string, string> parameters;
        public SimpleConverter() : base()
        {
            parameters = new Dictionary<string, string>()
            {
                {"partRevision","1.0" },
                {"operationTypeCode","40" }
            };
        }

        public Dictionary<string, string> ConverterParameters => parameters;

        public void CleanUp()
        {
        }

        public Report ImportReport(TDM api, Stream file)
        {
            UUTReport unitTestReport = null;
            using (TextReader reader = new StreamReader(file))
            {
                string line = reader.ReadLine();
                while (line != null)
                {
                    if (!string.IsNullOrEmpty(line) && !line.StartsWith("//"))
                    {
                        if (unitTestReport == null)
                            unitTestReport = CreateUUTFromHeader(api, line);
                        else
                            ReadMeasure(unitTestReport, line);
                    }
                    line = reader.ReadLine();
                }
            }
            return unitTestReport;
        }


        private UUTReport CreateUUTFromHeader(TDM api, string line)
        {
            //      0           1           2         3          4
            //Serialnumber;PartNumber;Operatorname;StartDate;SequenceName
            string[] fields = line.Split(new char[] { ';' });
            UUTReport uut = api.CreateUUTReport(
                fields[2],
                fields[1],
                parameters["partRevision"],
                fields[0],
                parameters["operationTypeCode"],
                fields[4],
                "1.0.0");
            uut.StartDateTime = DateTime.ParseExact(fields[3], "yyyy-MM-dd HH:mm:ss", CultureInfo.InvariantCulture);
            return uut;
        }
        private void ReadMeasure(UUTReport unitTestReport, string line)
        {
            //    0         1       2      3      4
            //Stepname; Measure; LowLim; HiLim; Unit
            string[] fields = line.Split(new char[] { ';' });
            unitTestReport.GetRootSequenceCall().AddNumericLimitStep(fields[0]).AddTest(
                double.Parse(fields[1], CultureInfo.InvariantCulture), CompOperatorType.GELE,
                double.Parse(fields[2], CultureInfo.InvariantCulture),
                double.Parse(fields[3], CultureInfo.InvariantCulture),
                fields[4]);
        }
    }
}
